@@ -8,7 +8,7 @@ def invoke_product_recommender(access_token: str, base_url: str, id: int, common
     json_params = {
         "commonUserId": common_user_id
     }
-    r = post(f'{base_url}/api/recommenders/ProductRecommender/{id}/invoke',
+    r = post(f'{base_url}/api/recommenders/ProductRecommenders/{id}/invoke',
              json_params, access_token)
     if r.ok:
         return r.json()
